@@ -1,12 +1,10 @@
 from sg import sg
-from MLab import *
 from numpy import *
 
 num=100
 weight=1.
-sg('loglevel', 'ALL')
 labels=concatenate((-ones([1,num]), ones([1,num])),1)[0]
-features=concatenate((randn(2,num)-1,randn(2,num)+1),1)
+features=concatenate((random.normal(size=(2,num))-1,random.normal(size=(2,num))+1),1)
 
 sg('c', 10.)
 sg('new_svm', 'LIBSVM')
