@@ -11,9 +11,9 @@ size_cache <- 10
 
 fm_train_real <- as.matrix(read.table('../data/fm_train_real.dat'))
 fm_test_real <- as.matrix(read.table('../data/fm_test_real.dat'))
-fm_train_dna <- as.matrix(read.table('../data/fm_train_dna.dat'))
-fm_test_dna <- as.matrix(read.table('../data/fm_test_dna.dat'))
-label_train_dna <- as.real(as.matrix(read.table('../data/label_train_dna42.dat')))
+fm_train_dna <- t(as.matrix(read.table('../data/fm_train_dna.dat')))
+fm_test_dna <- t(as.matrix(read.table('../data/fm_test_dna.dat')))
+label_train_dna <- as.real(as.matrix(read.table('../data/label_train_dna.dat')))
 
 
 #
@@ -389,6 +389,8 @@ km=sg('get_kernel_matrix')
 # Combined
 print('Combined')
 
+dump <- sg('clean_features', 'TRAIN')
+dump <- sg('clean_features', 'TEST')
 dump <- sg('set_kernel', 'COMBINED', size_cache)
 dump <- sg('add_kernel', 1, 'LINEAR', 'REAL', size_cache)
 dump <- sg('add_features', 'TRAIN', fm_train_real)
