@@ -6,7 +6,7 @@ function y = regression(filename)
 	eval('globals'); % ugly hack to have vars from filename as globals
 	eval(filename);
 
-	if ~set_features()
+	if ~set_features('kernel_')
 		return;
 	end
 
@@ -17,7 +17,7 @@ function y = regression(filename)
 	sg('threads', regression_num_threads);
 	sg('set_labels', 'TRAIN', regression_labels);
 
-	rname=fix_regression_name_inconsistency(name);
+	rname=fix_regression_name_inconsistency(regression_name);
 	try
 		sg('new_regression', rname);
 	catch
