@@ -6,15 +6,16 @@ from sg import sg
 import util
 
 
-def _evaluate (indata):
+def _evaluate (indata, prefix):
 	dmatrix=sg('get_distance_matrix')
-	dtrain=max(abs(indata['dm_train']-dmatrix).flat)
+	dm_train=max(abs(indata['distance_matrix_train']-dmatrix).flat)
 
 	sg('init_distance', 'TEST')
 	dmatrix=sg('get_distance_matrix')
-	dtest=max(abs(indata['dm_test']-dmatrix).flat)
+	dm_test=max(abs(indata['distance_matrix_test']-dmatrix).flat)
 
-	return util.check_accuracy(indata['accuracy'], dtrain=dtrain, dtest=dtest)
+	return util.check_accuracy(
+		indata[prefix+'accuracy'], dm_train=dm_train, dm_test=dm_test)
 
 
 ########################################################################
@@ -22,13 +23,14 @@ def _evaluate (indata):
 ########################################################################
 
 def test (indata):
+	prefix='distance_'
 	try:
-		util.set_features(indata)
+		util.set_features(indata, prefix)
 	except NotImplementedError, e:
 		print e
 		return True
 
 	util.set_and_train_distance(indata)
 
-	return _evaluate(indata)
+	return _evaluate(indata, prefix)
 
