@@ -5,11 +5,11 @@ preproc <- function(filename) {
 	source('util/tobool.R')
 	source('util/fix_preproc_name_inconsistency.R');
 
-	if (!set_features()) {
+	if (!set_features('kernel_')) {
 		return(TRUE)
 	}
 
-	pname <- fix_preproc_name_inconsistency(name)
+	pname <- fix_preproc_name_inconsistency(preproc_name)
 	if (regexpr('PRUNEVARSUBMEAN', pname)>0) {
 		sg('add_preproc', pname, tobool(preproc_arg0_divide))
 	} else {
@@ -24,12 +24,12 @@ preproc <- function(filename) {
 	}
 
 	kmatrix <- sg('get_kernel_matrix')
-	ktrain <- max(max(abs(km_train-kmatrix)))
+	km_train <- max(max(abs(kernel_matrix_train-kmatrix)))
 
 	sg('init_kernel', 'TEST');
 	kmatrix <- sg('get_kernel_matrix')
-	ktest <- max(max(abs(km_test-kmatrix)))
+	km_test <- max(max(abs(kernel_matrix_test-kmatrix)))
 
-	data <- list(ktrain, ktest)
-	return(check_accuracy(accuracy, 'kernel', data))
+	data <- list(km_train, km_test)
+	return(check_accuracy(kernel_accuracy, 'kernel', data))
 }
