@@ -5,7 +5,7 @@ regression <- function(filename) {
 	source('util/tobool.R')
 	source('util/fix_regression_name_inconsistency.R')
 
-	if (!set_features()) {
+	if (!set_features('kernel_')) {
 		return(TRUE)
 	}
 
@@ -16,7 +16,7 @@ regression <- function(filename) {
 	sg('threads', regression_num_threads)
 	sg('set_labels', 'TRAIN', regression_labels)
 
-	rname <- fix_regression_name_inconsistency(name)
+	rname <- fix_regression_name_inconsistency(regression_name)
 	try(sg('new_regression', rname))
 
 	if (regexpr('svm', regression_type)>0) {
